<img src="./branding/logo.png" height="60px">

matematik is a package for providing and solving basic math formulas

- Documentation : https://github.com/demirantay/matematik/blob/master/docs/index.md
- Sourcecode :https://github.com/demirantay/matematik
- PyPi : https://pypi.org/project/matematik/
- Website : coming soon ...

It provides:

- Arithmetic formulas
- Algebra1 formulas
- Algebra2 formulas
- Geometry formulas

You can find how to use the package through documentation.

#### FAQ

Q: Why even code something like this ?
<br>
A: The content of the package is not that important, I have coded this project to learn
   more about python packaging. However, the content of the package is still
   little bit useful for people who want to rapidly get the answer of a math formula.
